libcosmic/cosmic/cosmic_theme/palette/cast/trait.TryFromComponents.html

116 lines
49 KiB
HTML
Raw Normal View History

<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="Trait for trying to cast a collection of colors from a collection of color components without copying."><title>TryFromComponents in cosmic::cosmic_theme::palette::cast - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../../../../static.files/${f}">`).join(""))</script><link rel="stylesheet" href="../../../../static.files/normalize-9960930a.css"><link rel="stylesheet" href="../../../../static.files/rustdoc-aa0817cf.css"><meta name="rustdoc-vars" data-root-path="../../../../" data-static-root-path="../../../../static.files/" data-current-crate="cosmic" data-themes="" data-resource-suffix="" data-rustdoc-version="1.90.0-nightly (3048886e5 2025-07-30)" data-channel="nightly" data-search-js="search-fa3e91e5.js" data-settings-js="settings-5514c975.js" ><script src="../../../../static.files/storage-68b7e25d.js"></script><script defer src="sidebar-items.js"></script><script defer src="../../../../static.files/main-eebb9057.js"></script><noscript><link rel="stylesheet" href="../../../../static.files/noscript-32bb7600.css"></noscript><link rel="alternate icon" type="image/png" href="../../../../static.files/favicon-32x32-6580c154.png"><link rel="icon" type="image/svg+xml" href="../../../../static.files/favicon-044be391.svg"></head><body class="rustdoc trait"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="mobile-topbar"><button class="sidebar-menu-toggle" title="show sidebar"></button></nav><nav class="sidebar"><div class="sidebar-crate"><h2><a href="../../../../cosmic/index.html">cosmic</a><span class="version">1.0.0</span></h2></div><div class="sidebar-elems"><section id="rustdoc-toc"><h2 class="location"><a href="#">TryFrom<wbr>Components</a></h2><h3><a href="#">Sections</a></h3><ul class="block top-toc"><li><a href="#errors" title="Errors">Errors</a></li><li><a href="#examples" title="Examples">Examples</a></li></ul><h3><a href="#required-associated-types">Required Associated Types</a></h3><ul class="block"><li><a href="#associatedtype.Error" title="Error">Error</a></li></ul><h3><a href="#required-methods">Required Methods</a></h3><ul class="block"><li><a href="#tymethod.try_from_components" title="try_from_components">try_from_components</a></li></ul><h3><a href="#foreign-impls">Implementations on Foreign Types</a></h3><ul class="block"><li><a href="#impl-TryFromComponents%3C%26%5BT%5D%3E-for-%26%5BC%5D" title="&#38;&#39;a [C]">&#38;&#39;a [C]</a></li><li><a href="#impl-TryFromComponents%3C%26%5BT;+N%5D%3E-for-%26%5BC%5D" title="&#38;&#39;a [C]">&#38;&#39;a [C]</a></li><li><a href="#impl-TryFromComponents%3C%26Box%3C%5BT%5D%3E%3E-for-%26%5BC%5D" title="&#38;&#39;a [C]">&#38;&#39;a [C]</a></li><li><a href="#impl-TryFromComponents%3C%26Vec%3CT%3E%3E-for-%26%5BC%5D" title="&#38;&#39;a [C]">&#38;&#39;a [C]</a></li><li><a href="#impl-TryFromComponents%3C%26mut+%5BT%5D%3E-for-%26mut+%5BC%5D" title="&#38;&#39;a mut [C]">&#38;&#39;a mut [C]</a></li><li><a href="#impl-TryFromComponents%3C%26mut+%5BT;+N%5D%3E-for-%26mut+%5BC%5D" title="&#38;&#39;a mut [C]">&#38;&#39;a mut [C]</a></li><li><a href="#impl-TryFromComponents%3C%26mut+Box%3C%5BT%5D%3E%3E-for-%26mut+%5BC%5D" title="&#38;&#39;a mut [C]">&#38;&#39;a mut [C]</a></li><li><a href="#impl-TryFromComponents%3C%26mut+Vec%3CT%3E%3E-for-%26mut+%5BC%5D" title="&#38;&#39;a mut [C]">&#38;&#39;a mut [C]</a></li><li><a href="#impl-TryFromComponents%3C%5BT;+N%5D%3E-for-%5BC;+M%5D" title="[C; M]">[C; M]</a></
type <a href="#associatedtype.Error" class="associatedtype">Error</a>;
// Required method
fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(components: C) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;Self, Self::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;;
}</code></pre><details class="toggle top-doc" open><summary class="hideme"><span>Expand description</span></summary><div class="docblock"><p>Trait for trying to cast a collection of colors from a collection of color
components without copying.</p>
<p>This trait is meant as a more convenient alternative to the free functions
in <a href="index.html" title="mod cosmic::cosmic_theme::palette::cast"><code>cast</code></a>, to allow method chaining among other things.</p>
<h3 id="errors"><a class="doc-anchor" href="#errors"></a>Errors</h3>
<p>The cast will return an error if the cast fails, such as when the length of
the input is not a multiple of the colors array length.</p>
<h3 id="examples"><a class="doc-anchor" href="#examples"></a>Examples</h3>
<div class="example-wrap"><pre class="rust rust-example-rendered"><code><span class="kw">use </span>palette::{cast::TryFromComponents, Srgb};
<span class="kw">let </span>array: [<span class="kw">_</span>; <span class="number">6</span>] = [<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>];
<span class="kw">let </span>slice: <span class="kw-2">&amp;</span>[<span class="kw">_</span>] = <span class="kw-2">&amp;</span>[<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>];
<span class="kw">let </span>slice_mut: <span class="kw-2">&amp;mut </span>[<span class="kw">_</span>] = <span class="kw-2">&amp;mut </span>[<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>];
<span class="kw">let </span>vec: Vec&lt;<span class="kw">_</span>&gt; = <span class="macro">vec!</span>[<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>];
<span class="macro">assert_eq!</span>(
&lt;[Srgb&lt;u8&gt;; <span class="number">2</span>]&gt;::try_from_components(array),
<span class="prelude-val">Ok</span>([Srgb::new(<span class="number">64u8</span>, <span class="number">139</span>, <span class="number">10</span>), Srgb::new(<span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>)])
);
<span class="macro">assert_eq!</span>(
&lt;<span class="kw-2">&amp;</span>[Srgb&lt;u8&gt;]&gt;::try_from_components(slice),
<span class="prelude-val">Ok</span>([Srgb::new(<span class="number">64u8</span>, <span class="number">139</span>, <span class="number">10</span>), Srgb::new(<span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>)].as_ref())
);
<span class="macro">assert_eq!</span>(
&lt;<span class="kw-2">&amp;mut </span>[Srgb&lt;u8&gt;]&gt;::try_from_components(slice_mut),
<span class="prelude-val">Ok</span>([Srgb::new(<span class="number">64u8</span>, <span class="number">139</span>, <span class="number">10</span>), Srgb::new(<span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>)].as_mut())
);
<span class="macro">assert_eq!</span>(
Vec::&lt;Srgb&lt;u8&gt;&gt;::try_from_components(vec),
<span class="prelude-val">Ok</span>(<span class="macro">vec!</span>[Srgb::new(<span class="number">64u8</span>, <span class="number">139</span>, <span class="number">10</span>), Srgb::new(<span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>)])
);</code></pre></div>
<p>Owning types can be cast as slices, too:</p>
<div class="example-wrap"><pre class="rust rust-example-rendered"><code><span class="kw">use </span>palette::{cast::TryFromComponents, Srgb};
<span class="kw">let </span>array: [<span class="kw">_</span>; <span class="number">6</span>] = [<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>];
<span class="kw">let </span><span class="kw-2">mut </span>vec: Vec&lt;<span class="kw">_</span>&gt; = <span class="macro">vec!</span>[<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>];
<span class="macro">assert_eq!</span>(
&lt;<span class="kw-2">&amp;</span>[Srgb&lt;u8&gt;]&gt;::try_from_components(<span class="kw-2">&amp;</span>array),
<span class="prelude-val">Ok</span>([Srgb::new(<span class="number">64u8</span>, <span class="number">139</span>, <span class="number">10</span>), Srgb::new(<span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>)].as_ref())
);
<span class="macro">assert_eq!</span>(
&lt;<span class="kw-2">&amp;mut </span>[Srgb&lt;u8&gt;]&gt;::try_from_components(<span class="kw-2">&amp;mut </span>vec),
<span class="prelude-val">Ok</span>([Srgb::new(<span class="number">64u8</span>, <span class="number">139</span>, <span class="number">10</span>), Srgb::new(<span class="number">93</span>, <span class="number">18</span>, <span class="number">214</span>)].as_mut())
);</code></pre></div>
<p>This produces an error:</p>
<div class="example-wrap"><pre class="rust rust-example-rendered"><code><span class="kw">use </span>palette::{cast::TryFromComponents, Srgb};
<span class="kw">let </span>components = <span class="kw-2">&amp;</span>[<span class="number">64</span>, <span class="number">139</span>, <span class="number">10</span>, <span class="number">93</span>, <span class="number">18</span>]; <span class="comment">// Not a multiple of 3
</span><span class="macro">assert!</span>(&lt;<span class="kw-2">&amp;</span>[Srgb&lt;u8&gt;]&gt;::try_from_components(components).is_err());</code></pre></div>
</div></details><h2 id="required-associated-types" class="section-header">Required Associated Types<a href="#required-associated-types" class="anchor"></a></h2><div class="methods"><details class="toggle" open><summary><section id="associatedtype.Error" class="method"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#87">Source</a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a></h4></section></summary><div class="docblock"><p>The error for when <code>try_from_components</code> fails to cast.</p>
</div></details></div><h2 id="required-methods" class="section-header">Required Methods<a href="#required-methods" class="anchor"></a></h2><div class="methods"><details class="toggle method-toggle" open><summary><section id="tymethod.try_from_components" class="method"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#95">Source</a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(components: C) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;Self, Self::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></summary><div class="docblock"><p>Try to cast a collection of color components into an collection of
colors.</p>
<p>Return an error if the conversion cant be done, such as when the number
of items in <code>components</code> isnt a multiple of the number of components in
the color type.</p>
</div></details></div><h2 id="dyn-compatibility" class="section-header">Dyn Compatibility<a href="#dyn-compatibility" class="anchor"></a></h2><div class="dyn-compatibility-info"><p>This trait is <b>not</b> <a href="https://doc.rust-lang.org/nightly/reference/items/traits.html#dyn-compatibility">dyn compatible</a>.</p><p><i>In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.</i></p></div><h2 id="foreign-impls" class="section-header">Implementations on Foreign Types<a href="#foreign-impls" class="anchor"></a></h2><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26%5BT%5D%3E-for-%26%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#impl-TryFromComponents%3C%26%5BT%5D%3E-for-%26%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt; for &amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-1" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#associatedtype.Error-1" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#method.try_from_components" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26Box%3C%5BT%5D%3E%3E-for-%26%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#impl-TryFromComponents%3C%26Box%3C%5BT%5D%3E%3E-for-%26%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt; for &amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-2" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#associatedtype.Error-2" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-1" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#method.try_from_components-1" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26Vec%3CT%3E%3E-for-%26%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#impl-TryFromComponents%3C%26Vec%3CT%3E%3E-for-%26%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;&gt; for &amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-3" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#associatedtype.Error-3" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-2" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#method.try_from_components-2" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26mut+%5BT%5D%3E-for-%26mut+%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#impl-TryFromComponents%3C%26mut+%5BT%5D%3E-for-%26mut+%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt; for &amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-4" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#associatedtype.Error-4" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-3" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#method.try_from_components-3" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26mut+Box%3C%5BT%5D%3E%3E-for-%26mut+%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#impl-TryFromComponents%3C%26mut+Box%3C%5BT%5D%3E%3E-for-%26mut+%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt; for &amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-5" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#associatedtype.Error-5" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-4" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#method.try_from_components-4" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a mut <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26mut+Vec%3CT%3E%3E-for-%26mut+%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#impl-TryFromComponents%3C%26mut+Vec%3CT%3E%3E-for-%26mut+%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;&gt; for &amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-6" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#associatedtype.Error-6" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-5" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#148">Source</a><a href="#method.try_from_components-5" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a mut <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26%5BT;+N%5D%3E-for-%26%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#impl-TryFromComponents%3C%26%5BT;+N%5D%3E-for-%26%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C, const N: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>&gt; for &amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-7" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#associatedtype.Error-7" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-6" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#method.try_from_components-6" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%26mut+%5BT;+N%5D%3E-for-%26mut+%5BC%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#impl-TryFromComponents%3C%26mut+%5BT;+N%5D%3E-for-%26mut+%5BC%5D" class="anchor"></a><h3 class="code-header">impl&lt;'a, T, C, const N: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>&gt; for &amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a><div class="where">where
T: 'a,
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-8" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#associatedtype.Error-8" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.SliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::SliceCastError">SliceCastError</a></h4></section><section id="method.try_from_components-7" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#145">Source</a><a href="#method.try_from_components-7" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: &amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>, &lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;&amp;'a mut <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3C%5BT;+N%5D%3E-for-%5BC;+M%5D" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#98-101">Source</a><a href="#impl-TryFromComponents%3C%5BT;+N%5D%3E-for-%5BC;+M%5D" class="anchor"></a><h3 class="code-header">impl&lt;T, C, const N: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>, const M: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.usize.html">usize</a>&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>&gt; for <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[C; M]</a><div class="where">where
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-9" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#103">Source</a><a href="#associatedtype.Error-9" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="enum" href="../../../iced/enum.Never.html" title="enum cosmic::iced::Never">Infallible</a></h4></section><section id="method.try_from_components-8" class="method trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#106">Source</a><a href="#method.try_from_components-8" class="anchor"></a><h4 class="code-header">fn <a href="#tymethod.try_from_components" class="fn">try_from_components</a>(
components: <a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>,
) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[C; M]</a>, &lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[C; M]</a> as <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.array.html">[T; N]</a>&gt;&gt;::<a class="associatedtype" href="trait.TryFromComponents.html#associatedtype.Error" title="type cosmic::cosmic_theme::palette::cast::TryFromComponents::Error">Error</a>&gt;</h4></section></div></details><h2 id="implementors" class="section-header">Implementors<a href="#implementors" class="anchor"></a></h2><div id="implementors-list"><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3CBox%3C%5BT%5D%3E%3E-for-Box%3C%5BC%5D%3E" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#151-154">Source</a><a href="#impl-TryFromComponents%3CBox%3C%5BT%5D%3E%3E-for-Box%3C%5BC%5D%3E" class="anchor"></a><h3 class="code-header">impl&lt;T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;<a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[T]</a>&gt;&gt; for <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/boxed/struct.Box.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::boxed::Box">Box</a>&lt;<a class="primitive" href="https://doc.rust-lang.org/nightly/std/primitive.slice.html">[C]</a>&gt;<div class="where">where
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-10" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#156">Source</a><a href="#associatedtype.Error-10" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.BoxedSliceCastError.html" title="struct cosmic::cosmic_theme::palette::cast::BoxedSliceCastError">BoxedSliceCastError</a>&lt;T&gt;</h4></section></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFromComponents%3CVec%3CT%3E%3E-for-Vec%3CC%3E" class="impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#165-168">Source</a><a href="#impl-TryFromComponents%3CVec%3CT%3E%3E-for-Vec%3CC%3E" class="anchor"></a><h3 class="code-header">impl&lt;T, C&gt; <a class="trait" href="trait.TryFromComponents.html" title="trait cosmic::cosmic_theme::palette::cast::TryFromComponents">TryFromComponents</a>&lt;<a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;T&gt;&gt; for <a class="struct" href="../../../cctk/sctk/reexports/client/backend/smallvec/alloc/vec/struct.Vec.html" title="struct cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::vec::Vec">Vec</a>&lt;C&gt;<div class="where">where
C: <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>,
&lt;C as <a class="trait" href="trait.ArrayCast.html" title="trait cosmic::cosmic_theme::palette::cast::ArrayCast">ArrayCast</a>&gt;::<a class="associatedtype" href="trait.ArrayCast.html#associatedtype.Array" title="type cosmic::cosmic_theme::palette::cast::ArrayCast::Array">Array</a>: <a class="trait" href="../trait.ArrayExt.html" title="trait cosmic::cosmic_theme::palette::ArrayExt">ArrayExt</a>&lt;Item = T&gt;,</div></h3></section></summary><div class="impl-items"><section id="associatedtype.Error-11" class="associatedtype trait-impl"><a class="src rightside" href="https://docs.rs/palette/0.7.6/src/palette/cast/from_into_components_traits.rs.html#170">Source</a><a href="#associatedtype.Error-11" class="anchor"></a><h4 class="code-header">type <a href="#associatedtype.Error" class="associatedtype">Error</a> = <a class="struct" href="struct.VecCastError.html" title="struct cosmic::cosmic_theme::palette::cast::VecCastError">VecCastError</a>&lt;T&gt;</h4></section></div></details></div><script src="../../../../trait.impl/palette/cast/from_into_components_traits/trait.TryFromComponents.js" data-ignore-extern-crates="std,alloc" async></script></section></div></main></body></html>